@@ -18,41 +18,41 @@ import os
 ############################################## Team colors dictionary ##############################################
 
 NHL_COLORS = {
-		'ANA': {'GOAL': '#F47A38', 'SHOT': '#000000', 'MISS': '#D3D3D3'},
+        'ANA': {'GOAL': '#F47A38', 'SHOT': '#000000', 'MISS': '#D3D3D3'},
         'ATL': {'GOAL': '#5C88DA', 'SHOT': '#041E42', 'MISS': '#D3D3D3'},
-		#'ARI': {'GOAL': '#E2D6B5', 'SHOT': '#8C2633', 'MISS': '#D3D3D3'},
+        #'ARI': {'GOAL': '#E2D6B5', 'SHOT': '#8C2633', 'MISS': '#D3D3D3'},
         'ARI': {'GOAL': '#A9431E', 'SHOT': '#5F259F', 'MISS': '#D3D3D3'},
-		'BOS': {'GOAL': '#FFB81C', 'SHOT': '#000000', 'MISS': '#D3D3D3'},
-		'BUF': {'GOAL': '#FCB514', 'SHOT': '#002654', 'MISS': '#D3D3D3'},
-		'CAR': {'GOAL': '#CC0000', 'SHOT': '#000000', 'MISS': '#D3D3D3'},
-		'CBJ': {'GOAL': '#CE1126', 'SHOT': '#002654', 'MISS': '#D3D3D3'},
-		'CGY': {'GOAL': '#F1BE48', 'SHOT': '#C8102E', 'MISS': '#D3D3D3'},
+        'BOS': {'GOAL': '#FFB81C', 'SHOT': '#000000', 'MISS': '#D3D3D3'},
+        'BUF': {'GOAL': '#FCB514', 'SHOT': '#002654', 'MISS': '#D3D3D3'},
+        'CAR': {'GOAL': '#CC0000', 'SHOT': '#000000', 'MISS': '#D3D3D3'},
+        'CBJ': {'GOAL': '#CE1126', 'SHOT': '#002654', 'MISS': '#D3D3D3'},
+        'CGY': {'GOAL': '#F1BE48', 'SHOT': '#C8102E', 'MISS': '#D3D3D3'},
         'CHI': {'GOAL': '#CF0A2C', 'SHOT': '#000000', 'MISS': '#D3D3D3'},
-		'COL': {'GOAL': '#236192', 'SHOT': '#6F263D', 'MISS': '#D3D3D3'},
-		'DAL': {'GOAL': '#006847', 'SHOT': '#111111', 'MISS': '#D3D3D3'},
-		'DET': {'GOAL': '#FFFFFF', 'SHOT': '#CE1126', 'MISS': '#D3D3D3'},
-		'EDM': {'GOAL': '#FF4C00', 'SHOT': '#041E42', 'MISS': '#D3D3D3'},
-		'FLA': {'GOAL': '#C8102E', 'SHOT': '#041E42', 'MISS': '#D3D3D3'},
-		'LAK': {'GOAL': '#A2AAAD', 'SHOT': '#111111', 'MISS': '#D3D3D3'},
-		'MIN': {'GOAL': '#A6192E', 'SHOT': '#154734', 'MISS': '#D3D3D3'},
-		'MTL': {'GOAL': '#AF1E2D', 'SHOT': '#192168', 'MISS': '#D3D3D3'},
-		'NJD': {'GOAL': '#CE1126', 'SHOT': '#000000', 'MISS': '#D3D3D3'},
-		'NSH': {'GOAL': '#FFB81C', 'SHOT': '#041E42', 'MISS': '#D3D3D3'},
-		'NYI': {'GOAL': '#F47D30', 'SHOT': '#00539B', 'MISS': '#D3D3D3'},
-		'NYR': {'GOAL': '#CE1126', 'SHOT': '#0038A8', 'MISS': '#D3D3D3'},
-		'OTT': {'GOAL': '#C2912C', 'SHOT': '#C52032', 'MISS': '#D3D3D3'},
-		'PHI': {'GOAL': '#F74902', 'SHOT': '#000000', 'MISS': '#D3D3D3'},
-		'PIT': {'GOAL': '#FCB514', 'SHOT': '#000000', 'MISS': '#D3D3D3'},
-		'SEA': {'GOAL': '#99D9D9', 'SHOT': '#001628', 'MISS': '#D3D3D3'},
-		'SJS': {'GOAL': '#006D75', 'SHOT': '#000000', 'MISS': '#D3D3D3'},
-		'STL': {'GOAL': '#FCB514', 'SHOT': '#002F87', 'MISS': '#D3D3D3'},
-		'TBL': {'GOAL': '#FFFFFF', 'SHOT': '#002868', 'MISS': '#D3D3D3'},
-		'TOR': {'GOAL': '#FFFFFF', 'SHOT': '#00205B', 'MISS': '#D3D3D3'},
-		'VAN': {'GOAL': '#00843D', 'SHOT': '#00205B', 'MISS': '#D3D3D3'},
-		'VGK': {'GOAL': '#B4975A', 'SHOT': '#333F42', 'MISS': '#D3D3D3'},
-		'WSH': {'GOAL': '#C8102E', 'SHOT': '#041E42', 'MISS': '#D3D3D3'},
-		'WPG': {'GOAL': '#AC162C', 'SHOT': '#041E42', 'MISS': '#D3D3D3'},
-            	}
+        'COL': {'GOAL': '#236192', 'SHOT': '#6F263D', 'MISS': '#D3D3D3'},
+        'DAL': {'GOAL': '#006847', 'SHOT': '#111111', 'MISS': '#D3D3D3'},
+        'DET': {'GOAL': '#FFFFFF', 'SHOT': '#CE1126', 'MISS': '#D3D3D3'},
+        'EDM': {'GOAL': '#FF4C00', 'SHOT': '#041E42', 'MISS': '#D3D3D3'},
+        'FLA': {'GOAL': '#C8102E', 'SHOT': '#041E42', 'MISS': '#D3D3D3'},
+        'LAK': {'GOAL': '#A2AAAD', 'SHOT': '#111111', 'MISS': '#D3D3D3'},
+        'MIN': {'GOAL': '#A6192E', 'SHOT': '#154734', 'MISS': '#D3D3D3'},
+        'MTL': {'GOAL': '#AF1E2D', 'SHOT': '#192168', 'MISS': '#D3D3D3'},
+        'NJD': {'GOAL': '#CE1126', 'SHOT': '#000000', 'MISS': '#D3D3D3'},
+        'NSH': {'GOAL': '#FFB81C', 'SHOT': '#041E42', 'MISS': '#D3D3D3'},
+        'NYI': {'GOAL': '#F47D30', 'SHOT': '#00539B', 'MISS': '#D3D3D3'},
+        'NYR': {'GOAL': '#CE1126', 'SHOT': '#0038A8', 'MISS': '#D3D3D3'},
+        'OTT': {'GOAL': '#C2912C', 'SHOT': '#C52032', 'MISS': '#D3D3D3'},
+        'PHI': {'GOAL': '#F74902', 'SHOT': '#000000', 'MISS': '#D3D3D3'},
+        'PIT': {'GOAL': '#FCB514', 'SHOT': '#000000', 'MISS': '#D3D3D3'},
+        'SEA': {'GOAL': '#99D9D9', 'SHOT': '#001628', 'MISS': '#D3D3D3'},
+        'SJS': {'GOAL': '#006D75', 'SHOT': '#000000', 'MISS': '#D3D3D3'},
+        'STL': {'GOAL': '#FCB514', 'SHOT': '#002F87', 'MISS': '#D3D3D3'},
+        'TBL': {'GOAL': '#FFFFFF', 'SHOT': '#002868', 'MISS': '#D3D3D3'},
+        'TOR': {'GOAL': '#FFFFFF', 'SHOT': '#00205B', 'MISS': '#D3D3D3'},
+        'VAN': {'GOAL': '#00843D', 'SHOT': '#00205B', 'MISS': '#D3D3D3'},
+        'VGK': {'GOAL': '#B4975A', 'SHOT': '#333F42', 'MISS': '#D3D3D3'},
+        'WSH': {'GOAL': '#C8102E', 'SHOT': '#041E42', 'MISS': '#D3D3D3'},
+        'WPG': {'GOAL': '#AC162C', 'SHOT': '#041E42', 'MISS': '#D3D3D3'},
+                }
 
 ############################################## Helper functions ##############################################
 
@@ -93,8 +93,8 @@ def convert_to_list(obj):
 
 ############################################## One-game rink map function ##############################################
 
-def game_rink_map(data, good_team = None, title = None, strengths = ['all', '5v5', 'PP', 'SH', 'EV', '3v3'],
-                        colors = None, save_img = False, default_colors = NHL_COLORS):
+def game_rink_map(data, good_team = None, title = None, size = None, strengths = ['all', '5v5', 'PP', 'SH', 'EV', '3v3'],
+                        colors = None, save_img = False, annotations = False, default_colors = NHL_COLORS):
     
     '''
     Function to normalize coordinates to one zone
@@ -140,11 +140,12 @@ def game_rink_map(data, good_team = None, title = None, strengths = ['all', '5v5
 
         colors.update({good_team: default_colors[good_team]})
 
+
+    game_date = data.game_date.iloc[0].strftime('%b %d, %Y')
+
     if title == None:
 
         data.game_date = pd.to_datetime(data.game_date, infer_datetime_format = True)
-
-        game_date = data.game_date.iloc[0].strftime('%b %d, %Y')
         
         home_team = data.home_team.iloc[0]
         
@@ -198,15 +199,15 @@ def game_rink_map(data, good_team = None, title = None, strengths = ['all', '5v5
 
         elif strength == 'PP':
 
-        	subtitle = 'Power play shot attempts | @chickenandstats\n\n'
+            subtitle = 'Power play shot attempts | @chickenandstats\n\n'
 
-        	pp_list = ['5v4', '5v3']
+            pp_list = ['5v4', '5v3']
 
-        	df = some_df[some_df.strength_state.isin(pp_list)].copy()
+            df = some_df[some_df.strength_state.isin(pp_list)].copy()
 
-        	if df.empty:
+            if df.empty:
 
-        		continue
+                continue
 
         elif strength == 'SH':
 
@@ -238,7 +239,7 @@ def game_rink_map(data, good_team = None, title = None, strengths = ['all', '5v5
 
             if df.empty:
 
-            	continue
+                continue
 
             subtitle = f'{strength} shot attempts | @chickenandstats\n\n'
 
@@ -293,7 +294,7 @@ def game_rink_map(data, good_team = None, title = None, strengths = ['all', '5v5
 
             for result, color in colors_dict.items():
 
-                event_df = plot_df[plot_df.event == result]
+                event_df = plot_df[plot_df.event == result].copy()
 
                 if result == 'GOAL':
 
@@ -303,13 +304,34 @@ def game_rink_map(data, good_team = None, title = None, strengths = ['all', '5v5
 
                     edge_color = None
 
-                rink.scatter(event_df.norm_coords_x, event_df.norm_coords_y, c = color, label = result, s = 250, alpha = 0.8,
+                    
+                if size == None:
+                    
+                    s = 250
+                    
+                else:
+                    
+                    s = event_df[size] * 500
+                
+                rink.scatter(event_df.norm_coords_x, event_df.norm_coords_y, c = color, label = result, s = s, alpha = 0.8,
                     ax = ax, edgecolors = edge_color, is_constrained = True, zorder = zorder_dict[result])
 
                 
-                if result != 'GOAL':
+                if result == 'GOAL':
                     
-                    ax.set_zorder(-1)
+                    if annotations == True:
+                        
+                        event_df['new_x'], event_df['new_y'] = rink.convert_xy(event_df.norm_coords_x + 1.2, event_df.norm_coords_y - 1.2)
+                        
+                        for idx in event_df.index:
+                            
+                            ax.annotate(event_df['event_player_1'][idx],
+                                        (event_df['new_x'][idx], event_df['new_y'][idx]),
+                                        bbox=dict(boxstyle = 'round', fc="white", ec="gray", alpha = 0.75)
+                                       ).set_zorder(1000)
+                    
+                    #for i in range(len(x)):
+                     #   plt.annotate(text[i], (x[i], y[i] + 0.2))
             #img_path = f'/Users/scott/Documents/Sports Blog/Open source/logos/{team}.png'
 
             #img = mpimg.imread(img_path)
@@ -320,6 +342,7 @@ def game_rink_map(data, good_team = None, title = None, strengths = ['all', '5v5
 
                 ax.legend(loc="lower center", ncol=3, title = f'{team}', fontsize = 14,
                             title_fontsize = 16, facecolor = 'white', framealpha = 1, edgecolor = 'gray').set_zorder(-1)
+                
             if team == bad_team:
 
                 ax.legend(loc="upper center", ncol=3, title = f'{team}', fontsize = 14,
@@ -330,20 +353,5 @@ def game_rink_map(data, good_team = None, title = None, strengths = ['all', '5v5
 
                 os.makedirs('rink_plots')
 
-            fig.savefig(f'rink_plots/{good_team}_{bad_team}_{strength}.png', dpi = 750, bbox_inches = 'tight', facecolor = 'white')
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
+            fig.savefig(f'rink_plots/{good_team}_{bad_team}_{strength}_{game_date}.png', dpi = 750, bbox_inches = 'tight', facecolor = 'white')
 
